.. _examples:

========
Examples
========

Some lower-level examples of features of the ctapipe API (see
the Tutorials section for more complete examples)

.. toctree::
    :maxdepth: 1
    :caption: Algorithms

    dilate_image
    nd_interpolation
    convert_hex_to_square

.. toctree::
    :maxdepth: 1
    :caption: Core functionality

    InstrumentDescription
    camera_display
    containers
    Tools
    provenance
    table_writer_reader
    containers_with_enums_and_table_writer
